@@ -59,8 +59,10 @@
  #else
   #include "audiocapture_alsa.h"
  #endif
+#elif QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+ #include "audiocapture_qt5.h"
 #else
- #include "audiocapture_qt.h"
+ #include "audiocapture_qt6.h"
 #endif
 
 Doc::Doc(QObject* parent, int universes)
@@ -286,8 +288,10 @@ QSharedPointer<AudioCapture> Doc::audioInputCapture()
 #else
             new AudioCaptureAlsa()
 #endif
+#elif QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+            new AudioCaptureQt6()
 #else
-            new AudioCaptureQt()
+            new AudioCaptureQt6()
 #endif
             );
     }
@@ -457,14 +461,14 @@ bool Doc::addFixture(Fixture* fixture, quint32 id)
     QList<int> forcedLTP = fixture->forcedLTPChannels();
     quint32 fxAddress = fixture->address();
 
-    for (i = 0 ; i < fixture->channels(); i++)
+    for (i = 0; i < fixture->channels(); i++)
     {
         const QLCChannel *channel(fixture->channel(i));
 
         // Inform Universe of any HTP/LTP forcing
-        if (forcedHTP.contains(i))
+        if (forcedHTP.contains(int(i)))
             universes.at(uni)->setChannelCapability(fxAddress + i, channel->group(), Universe::HTP);
-        else if (forcedLTP.contains(i))
+        else if (forcedLTP.contains(int(i)))
             universes.at(uni)->setChannelCapability(fxAddress + i, channel->group(), Universe::LTP);
         else
             universes.at(uni)->setChannelCapability(fxAddress + i, channel->group());
@@ -616,9 +620,9 @@ bool Doc::updateFixtureChannelCapabilities(quint32 id, QList<int> forcedHTP, QLi
         const QLCChannel *channel(fixture->channel(i));
 
         // Inform Universe of any HTP/LTP forcing
-        if (forcedHTP.contains(i))
+        if (forcedHTP.contains(int(i)))
             universe->setChannelCapability(fxAddress + i, channel->group(), Universe::HTP);
-        else if (forcedLTP.contains(i))
+        else if (forcedLTP.contains(int(i)))
             universe->setChannelCapability(fxAddress + i, channel->group(), Universe::LTP);
         else
             universe->setChannelCapability(fxAddress + i, channel->group());
