@@ -141,7 +141,7 @@ void App::startup()
     m_ioManager = new InputOutputManager(this, m_doc);
     m_fixtureBrowser = new FixtureBrowser(this, m_doc);
     m_fixtureManager = new FixtureManager(this, m_doc);
-    m_fixtureGroupEditor = new FixtureGroupEditor(this, m_doc);
+    m_fixtureGroupEditor = new FixtureGroupEditor(this, m_doc, m_fixtureManager);
     m_functionManager = new FunctionManager(this, m_doc);
     m_simpleDesk = new SimpleDesk(this, m_doc);
     m_contextManager = new ContextManager(this, m_doc, m_fixtureManager, m_functionManager, m_simpleDesk);
@@ -161,6 +161,7 @@ void App::startup()
     rootContext()->setContextProperty("tardis", m_tardis);
 
     m_contextManager->registerContext(m_virtualConsole);
+    m_contextManager->registerContext(m_simpleDesk);
     m_contextManager->registerContext(m_showManager);
     m_contextManager->registerContext(m_ioManager);
 
@@ -168,7 +169,7 @@ void App::startup()
     qmlRegisterUncreatableType<ContextManager>("org.qlcplus.classes", 1, 0, "ContextManager", "Can't create a ContextManager!");
     qmlRegisterUncreatableType<ShowManager>("org.qlcplus.classes", 1, 0, "ShowManager", "Can't create a ShowManager!");
     qmlRegisterUncreatableType<NetworkManager>("org.qlcplus.classes", 1, 0, "NetworkManager", "Can't create a NetworkManager!");
-    qmlRegisterUncreatableType<SimpleDesk>("org.qlcplus.classes", 1, 0, "SimpleDesk", "Can't create a NetworkManager!");
+    qmlRegisterUncreatableType<SimpleDesk>("org.qlcplus.classes", 1, 0, "SimpleDesk", "Can't create a SimpleDesk!");
 
     // Start up in non-modified state
     m_doc->resetModified();
@@ -238,11 +239,17 @@ int App::accessMask() const
 
 bool App::is3DSupported() const
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (openglContext() == nullptr)
         return false;
 
     int glVersion = (openglContext()->format().majorVersion() * 10) + openglContext()->format().minorVersion();
     return glVersion < 33 ? false : true;
+#else
+    // TODO: Qt6
+
+    return true;
+#endif
 }
 
 void App::exit()
@@ -298,10 +305,14 @@ bool App::event(QEvent *event)
 
 void App::slotSceneGraphInitialized()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (openglContext() == nullptr)
         return;
 
     qDebug() << "OpenGL version: " << openglContext()->format().majorVersion() << openglContext()->format().minorVersion();
+#else
+    // TODO: Qt6
+#endif
 }
 
 void App::slotScreenChanged(QScreen *screen)
@@ -787,8 +798,9 @@ QFile::FileError App::saveXML(const QString& fileName)
     QXmlStreamWriter doc(&file);
     doc.setAutoFormatting(true);
     doc.setAutoFormattingIndent(1);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     doc.setCodec("UTF-8");
-
+#endif
     doc.writeStartDocument();
     doc.writeDTD(QString("<!DOCTYPE %1>").arg(KXMLQLCWorkspace));
 
