@@ -31,7 +31,6 @@
 #include "qlccapability.h"
 #include "qlcfixturedef.h"
 #include "treemodelitem.h"
-#include "colorfilters.h"
 #include "fixtureutils.h"
 #include "treemodel.h"
 #include "qlcconfig.h"
@@ -55,6 +54,7 @@ FixtureManager::FixtureManager(QQuickView *view, Doc *doc, QObject *parent)
     , m_maxTiltDegrees(0)
     , m_minBeamDegrees(15.0)
     , m_maxBeamDegrees(0)
+    , m_invertedZoom(false)
     , m_colorsMask(0)
 {
     Q_ASSERT(m_doc != nullptr);
@@ -266,10 +266,22 @@ bool FixtureManager::addFixture(QString manuf, QString model, QString mode, QStr
 
     // temporarily disconnect this signal since we want to use the given position
     disconnect(m_doc, SIGNAL(fixtureAdded(quint32)), this, SLOT(slotFixtureAdded(quint32)));
+    quint32 fxAddress = address;
 
     for (int i = 0; i < quantity; i++)
     {
         Fixture *fxi = new Fixture(m_doc);
+        //quint32 fxAddress = address + (i * channels) + (i * gap);
+        if (fxAddress + channels >= UNIVERSE_SIZE)
+        {
+            uniIdx++;
+            if (m_doc->inputOutputMap()->getUniverseID(uniIdx) == m_doc->inputOutputMap()->invalidUniverse())
+            {
+                m_doc->inputOutputMap()->addUniverse();
+                m_doc->inputOutputMap()->startUniverses();
+            }
+            fxAddress = 0;
+        }
 
         /* If we're adding more than one fixture,
            append a number to the end of the name */
@@ -277,7 +289,7 @@ bool FixtureManager::addFixture(QString manuf, QString model, QString mode, QStr
             fxi->setName(QString("%1 #%2").arg(name).arg(i + 1));
         else
             fxi->setName(name);
-        fxi->setAddress(address + (i * channels) + (i * gap));
+        fxi->setAddress(fxAddress);
         fxi->setUniverse(uniIdx);
         if (fxiDef == nullptr && fxiMode == nullptr)
         {
@@ -299,6 +311,8 @@ bool FixtureManager::addFixture(QString manuf, QString model, QString mode, QStr
         Tardis::instance()->enqueueAction(Tardis::FixtureCreate, fxi->id(), QVariant(),
                                           Tardis::instance()->actionToByteArray(Tardis::FixtureCreate, fxi->id()));
         slotFixtureAdded(fxi->id(), QVector3D(xPos, yPos, 0));
+
+        fxAddress += (channels + gap);
     }
 
     connect(m_doc, SIGNAL(fixtureAdded(quint32)), this, SLOT(slotFixtureAdded(quint32)));
@@ -354,6 +368,27 @@ bool FixtureManager::deleteFixtures(QVariantList IDList)
     return true;
 }
 
+bool FixtureManager::deleteFixtureInGroup(quint32 groupID, quint32 itemID, QString path)
+{
+    FixtureGroup *group = m_doc->fixtureGroup(groupID);
+    if (group == nullptr)
+        return false;
+
+    quint32 fxID = FixtureUtils::itemFixtureID(itemID);
+    //quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
+    //quint16 linkedIndex = FixtureUtils::itemLinkedIndex(itemID);
+
+    //TODO: tardis
+
+    qDebug() << "Removing fixture" << fxID << "from group" << group->name();
+    group->resignFixture(fxID);
+
+    m_fixtureTree->removeItem(path);
+    emit groupsTreeModelChanged();
+
+    return true;
+}
+
 void FixtureManager::renameFixture(quint32 itemID, QString newName)
 {
     quint32 fixtureID = FixtureUtils::itemFixtureID(itemID);
@@ -381,11 +416,7 @@ QVariant FixtureManager::groupsTreeModel()
     {
         m_fixtureTree = new TreeModel(this);
         QQmlEngine::setObjectOwnership(m_fixtureTree, QQmlEngine::CppOwnership);
-        QStringList treeColumns;
-        treeColumns << "classRef" << "type" << "id" << "subid" << "chIdx";
-        m_fixtureTree->setColumnNames(treeColumns);
-        m_fixtureTree->enableSorting(false);
-        updateGroupsTree(m_doc, m_fixtureTree, m_searchFilter, m_treeShowFlags);
+        setPropertyEditEnabled(false);
     }
 
     return QVariant::fromValue(m_fixtureTree);
@@ -398,13 +429,10 @@ bool FixtureManager::propertyEditEnabled()
 
 void FixtureManager::setPropertyEditEnabled(bool enable)
 {
-    if (enable == m_propertyEditEnabled)
-        return;
-
     m_propertyEditEnabled = enable;
 
     QStringList treeColumns;
-    treeColumns << "classRef" << "type" << "id" << "subid" << "chIdx";
+    treeColumns << "classRef" << "type" << "id" << "subid" << "chIdx" << "inGroup";
 
     if (enable)
     {
@@ -419,6 +447,7 @@ void FixtureManager::setPropertyEditEnabled(bool enable)
     emit propertyEditEnabledChanged();
 
     m_fixtureTree->setColumnNames(treeColumns);
+    m_fixtureTree->enableSorting(false);
     updateGroupsTree(m_doc, m_fixtureTree, m_searchFilter, m_treeShowFlags);
     emit groupsTreeModelChanged();
 }
@@ -488,7 +517,7 @@ void FixtureManager::setItemRoleData(int itemID, int index, QString role, QVaria
     QStringList uniNames = m_doc->inputOutputMap()->universeNames();
     int roleIndex = m_fixtureTree->roleIndex(role);
     if (linkedIndex)
-        fxName = m_monProps->fixtureResource(fixtureID, headIndex, linkedIndex);
+        fxName = m_monProps->fixtureName(fixtureID, headIndex, linkedIndex);
 
     if (index == -1)
     {
@@ -553,7 +582,7 @@ void FixtureManager::addFixtureNode(Doc *doc, TreeModel *treeModel, Fixture *fix
 
         QString fxName = fixture->name();
         if (linkedIndex)
-            fxName = monProps->fixtureResource(fixture->id(), headIndex, linkedIndex);
+            fxName = monProps->fixtureName(fixture->id(), headIndex, linkedIndex);
 
         QString fxPath = QString("%1%2%3").arg(basePath).arg(TreeModel::separator()).arg(fxName);
 
@@ -573,6 +602,7 @@ void FixtureManager::addFixtureNode(Doc *doc, TreeModel *treeModel, Fixture *fix
                     headParams.append(iID); // id
                     headParams.append(nodeSubID); // subid
                     headParams.append(headIdx); // chIdx
+                    headParams.append(false); // inGroup
                     treeModel->addItem(QString("%1 %2").arg(tr("Head")).arg(headIdx + 1, 3, 10, QChar('0')),
                                        headParams, fxPath);
                 }
@@ -603,6 +633,7 @@ void FixtureManager::addFixtureNode(Doc *doc, TreeModel *treeModel, Fixture *fix
                     chParams.append(itemID); // id
                     chParams.append(nodeSubID); // subid
                     chParams.append(chIdx); // chIdx
+                    chParams.append(false); // inGroup
 
                     if (showFlags & ShowFlags)
                         chParams.append(0); // might be useful in the future
@@ -647,6 +678,7 @@ void FixtureManager::addFixtureNode(Doc *doc, TreeModel *treeModel, Fixture *fix
             fxParams.append(itemID); // id
             fxParams.append(nodeSubID); // subid
             fxParams.append(0); // chIdx
+            fxParams.append(false); // inGroup
 
             if (showFlags & ShowFlags)
                 fxParams.append(monProps->fixtureFlags(fixture->id(), headIndex, linkedIndex));
@@ -708,6 +740,7 @@ void FixtureManager::addFixtureGroupTreeNode(Doc *doc, TreeModel *treeModel, Fix
             headParams.append(itemID); // id
             headParams.append(group->id()); // subid
             headParams.append(head.head); // chIdx
+            headParams.append(true); // inGroup
             treeModel->addItem(QString("%1 %2").arg(tr("Head")).arg(head.head + 1, 3, 10, QChar('0')),
                                headParams, fxPath);
 
@@ -719,6 +752,7 @@ void FixtureManager::addFixtureGroupTreeNode(Doc *doc, TreeModel *treeModel, Fix
                 fxParams.append(itemID); // id
                 fxParams.append(group->id()); // subid
                 fxParams.append(0); // chIdx
+                fxParams.append(true); // inGroup
 
                 treeModel->setPathData(fxPath, fxParams);
                 fixtureIDList.append(head.fxi);
@@ -733,6 +767,9 @@ void FixtureManager::addFixtureGroupTreeNode(Doc *doc, TreeModel *treeModel, Fix
         grpParams.append(QVariant::fromValue(group)); // classRef
         grpParams.append(App::FixtureGroupDragItem); // type
         grpParams.append(group->id()); // id
+        grpParams.append(0); // subid
+        grpParams.append(0); // chIdx
+        grpParams.append(true); // inGroup
 
         treeModel->setPathData(group->name(), grpParams);
     }
@@ -773,8 +810,6 @@ void FixtureManager::updateGroupsTree(Doc *doc, TreeModel *treeModel, QString se
         QString universeName = uniNames.at(fixture->universe());
         int matchMask = 0;
 
-        qDebug() << "----> add fixture:" << fixture->name();
-
         addFixtureNode(doc, treeModel, fixture, universeName, fixture->universe(),
                        matchMask, searchFilter, showFlags, checkedChannels);
     }
@@ -786,6 +821,9 @@ void FixtureManager::updateGroupsTree(Doc *doc, TreeModel *treeModel, QString se
         uniParams.append(QVariant::fromValue(universe)); // classRef
         uniParams.append(App::UniverseDragItem); // type
         uniParams.append(universe->id()); // id
+        uniParams.append(0); // subid
+        uniParams.append(0); // chIdx
+        uniParams.append(false); // inGroup
 
         treeModel->setPathData(universe->name(), uniParams);
     }
@@ -828,7 +866,7 @@ void FixtureManager::updateLinkedFixtureNode(quint32 itemID, bool add)
         return;
 
     QString universeName = uniNames.at(fixture->universe());
-    QString fixtureName = monProps->fixtureResource(fixtureID, headIndex, linkedIndex);
+    QString fixtureName = monProps->fixtureName(fixtureID, headIndex, linkedIndex);
 
     if (add)
     {
@@ -838,6 +876,7 @@ void FixtureManager::updateLinkedFixtureNode(quint32 itemID, bool add)
         fxParams.append(itemID); // id
         fxParams.append(fixture->universe()); // subid
         fxParams.append(0); // chIdx
+        fxParams.append(false); // inGroup
         fxParams.append(monProps->fixtureFlags(fixture->id(), headIndex, linkedIndex));
 
         m_fixtureTree->addItem(fixtureName, fxParams, universeName, 0);
@@ -1013,8 +1052,9 @@ void FixtureManager::updateFixtureGroup(quint32 groupID, quint32 itemID, int hea
         fxParams.append(itemID); // id
         fxParams.append(group->id()); // subid
         fxParams.append(0); // chIdx
+        fxParams.append(true); // inGroup
 
-        fxItem = m_fixtureTree->addItem(fixture->name(), fxParams, group->name(), TreeModel::EmptyNode);
+        m_fixtureTree->addItem(fixture->name(), fxParams, group->name(), TreeModel::EmptyNode);
     }
 
     for (int hIdx : headsList)
@@ -1025,12 +1065,25 @@ void FixtureManager::updateFixtureGroup(quint32 groupID, quint32 itemID, int hea
         headParams.append(itemID); // id
         headParams.append(group->id()); // subid
         headParams.append(hIdx); // chIdx
+        headParams.append(true); // inGroup
         m_fixtureTree->addItem(QString("%1 %2").arg(tr("Head")).arg(hIdx + 1, 3, 10, QChar('0')), headParams, fxPath);
     }
 
     //m_fixtureTree->printTree(); // enable for debug purposes
 }
 
+void FixtureManager::renameFixtureGroup(quint32 groupID, QString newName)
+{
+    FixtureGroup *group = m_doc->fixtureGroup(groupID);
+    if (group == nullptr)
+        return;
+
+    group->setName(newName);
+
+    updateGroupsTree(m_doc, m_fixtureTree, m_searchFilter);
+    emit groupsTreeModelChanged();
+}
+
 bool FixtureManager::deleteFixtureGroups(QVariantList IDList)
 {
     for (QVariant id : IDList)
@@ -1160,7 +1213,7 @@ bool FixtureManager::addRGBPanel(QString name, qreal xPos, qreal yPos)
         }
 
         fxi->setUniverse(m_doc->inputOutputMap()->getUniverseID(uniIndex));
-        fxi->setAddress(address);
+        fxi->setAddress(address - 1);
         address += fxi->channels();
         m_doc->addFixture(fxi);
 
@@ -1389,7 +1442,7 @@ bool FixtureManager::loadColorFilters(const QDir &dir, bool user)
 
         if (path.toLower().endsWith(KExtColorFilters) == true)
         {
-            ColorFilters* colFilter = new ColorFilters();
+            ColorFilters *colFilter = new ColorFilters();
             Q_ASSERT(colFilter != nullptr);
 
             QFile::FileError error = colFilter->loadXML(path);
@@ -1523,11 +1576,6 @@ void FixtureManager::setPresetValue(quint32 fixtureID, int chIndex, quint8 value
     emit presetChanged(ch, value);
 }
 
-void FixtureManager::setBeamValue(quint8 value)
-{
-    emit channelTypeValueChanged(QLCChannel::Beam, value);
-}
-
 void FixtureManager::updateCapabilityCounter(bool update, QString capName, int delta)
 {
     if (update == false)
@@ -1536,7 +1584,12 @@ void FixtureManager::updateCapabilityCounter(bool update, QString capName, int d
     QQuickItem *capItem = qobject_cast<QQuickItem*>(m_view->rootObject()->findChild<QObject *>(capName));
     if (capItem != nullptr)
     {
-        capItem->setProperty("counter", capItem->property("counter").toInt() + delta);
+        int count = capItem->property("counter").toInt() + delta;
+        capItem->setProperty("counter", count);
+
+        if (count == 0)
+            return;
+
         if (capName == "capPosition")
         {
             capItem->setProperty("panDegrees", m_maxPanDegrees);
@@ -1544,9 +1597,10 @@ void FixtureManager::updateCapabilityCounter(bool update, QString capName, int d
         }
         else if (capName == "capBeam")
         {
-            capItem->setProperty("minBeamDegrees", m_minBeamDegrees);
-            capItem->setProperty("maxBeamDegrees", m_maxBeamDegrees);
-
+            QMetaObject::invokeMethod(capItem, "setZoomRange",
+                    Q_ARG(QVariant, m_minBeamDegrees),
+                    Q_ARG(QVariant, m_maxBeamDegrees),
+                    Q_ARG(QVariant, m_invertedZoom));
         }
     }
 }
@@ -1711,17 +1765,26 @@ QMultiHash<int, SceneValue> FixtureManager::getFixtureCapabilities(quint32 itemI
             break;
             case QLCChannel::Beam:
             {
+                if (channel->preset() != QLCChannel::BeamZoomBigSmall &&
+                    channel->preset() != QLCChannel::BeamZoomSmallBig)
+                    break;
+
                 hasBeam = true;
-                if(fixture->fixtureMode() != nullptr)
+                if (fixture->fixtureMode() != nullptr)
                 {
-                    double minDeg = phy.lensDegreesMin();
-                    double maxDeg = phy.lensDegreesMax();
-                    if (minDeg == 0) minDeg = 15.0;
-                    if (maxDeg == 0) maxDeg = 30.0;
-                    if (minDeg < m_minBeamDegrees)
-                        m_minBeamDegrees = minDeg;
-                    if (maxDeg > m_maxBeamDegrees)
-                        m_maxBeamDegrees = maxDeg;
+                    m_minBeamDegrees = phy.lensDegreesMin();
+
+                    if (phy.lensDegreesMax() > m_maxBeamDegrees)
+                        m_maxBeamDegrees = phy.lensDegreesMax();
+
+                    if (m_maxBeamDegrees == 0)
+                        m_maxBeamDegrees = 30.0;
+
+                    // this considers only the last selected fixture
+                    if (channel->preset() == QLCChannel::BeamZoomBigSmall)
+                        m_invertedZoom = true;
+                    else
+                        m_invertedZoom = false;
                 }
                 channelsMap.insert(chType, SceneValue(fixtureID, ch));
             }
@@ -1763,6 +1826,15 @@ QList<SceneValue> FixtureManager::getFixturePosition(quint32 fxID, int type, int
     return fixture->positionToValues(type, degrees);
 }
 
+QList<SceneValue> FixtureManager::getFixtureZoom(quint32 fxID, float degrees)
+{
+    Fixture *fixture = m_doc->fixture(fxID);
+    if (fixture == nullptr || fixture->fixtureMode() == nullptr)
+        return QList<SceneValue>();
+
+    return fixture->zoomToValues(degrees);
+}
+
 QVariantList FixtureManager::presetsChannels(QLCChannel::Group group)
 {
     QVariantList prList;
