@@ -28,13 +28,13 @@
 #include <QDir>
 
 #include "scenevalue.h"
+#include "colorfilters.h"
 
 class Doc;
 class Fixture;
 class TreeModel;
 class TreeModelItem;
 class FixtureGroup;
-class ColorFilters;
 class MonitorProperties;
 
 class FixtureManager : public QObject
@@ -165,6 +165,8 @@ public:
     /** Delete some existing Fixtures with IDs provided by $IDList */
     Q_INVOKABLE bool deleteFixtures(QVariantList IDList);
 
+    Q_INVOKABLE bool deleteFixtureInGroup(quint32 groupID, quint32 itemID, QString path);
+
     /** Rename the Fixture with the provided $itemID to $newName */
     Q_INVOKABLE void renameFixture(quint32 itemID, QString newName);
 
@@ -260,6 +262,8 @@ public:
 
     Q_INVOKABLE void updateFixtureGroup(quint32 groupID, quint32 itemID, int headIdx);
 
+    Q_INVOKABLE void renameFixtureGroup(quint32 groupID, QString newName);
+
     /** Delete some existing Fixture Groups with IDs provided by $IDList */
     Q_INVOKABLE bool deleteFixtureGroups(QVariantList IDList);
 
@@ -384,7 +388,6 @@ public:
     Q_INVOKABLE void setColorValue(quint8 red, quint8 green, quint8 blue,
                                    quint8 white, quint8 amber, quint8 uv);
     Q_INVOKABLE void setPresetValue(quint32 fixtureID, int chIndex, quint8 value);
-    Q_INVOKABLE void setBeamValue(quint8 value);
 
     /**
      * @brief setFixtureCapabilities
@@ -405,6 +408,8 @@ public:
      *  It also provides multiple results if multiple heads are available */
     QList<SceneValue> getFixturePosition(quint32 fxID, int type, int degrees);
 
+    QList<SceneValue> getFixtureZoom(quint32 fxID, float degrees);
+
     /** Returns the names of the currently selected fixtures with gobo channels.
      *  The names are in the format: Product - Channel name */
     QVariantList goboChannels();
@@ -481,6 +486,7 @@ private:
 
     double m_minBeamDegrees;
     double m_maxBeamDegrees;
+    bool m_invertedZoom;
 
     /** Bitmask holding the colors supported by the currently selected fixtures */
     int m_colorsMask;
