@@ -28,9 +28,13 @@
 
 #include <Qt3DCore/QTransform>
 #include <Qt3DCore/QNode>
-#include <Qt3DRender/QGeometry>
-#include <Qt3DRender/QAttribute>
-#include <Qt3DRender/QBuffer>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+ #include <Qt3DRender/QGeometry>
+ #include <Qt3DRender/QAttribute>
+ #include <Qt3DRender/QBuffer>
+#else
+ #include <Qt3DCore/QAttribute>
+#endif
 #include <Qt3DRender/QParameter>
 #include <Qt3DExtras/QPhongMaterial>
 
@@ -38,6 +42,7 @@
 #include "tardis.h"
 #include "qlcfile.h"
 #include "qlcconfig.h"
+#include "listmodel.h"
 #include "mainview3d.h"
 #include "fixtureutils.h"
 #include "qlccapability.h"
@@ -80,6 +85,11 @@ MainView3D::MainView3D(QQuickView *view, Doc *doc, QObject *parent)
     // the order of StageType enum in MonitorProperties class
     m_stagesList << tr("Simple ground") << tr("Simple box") << tr("Rock stage") << tr("Theatre stage");
     m_stageResourceList << "qrc:/StageSimple.qml" << "qrc:/StageBox.qml" << "qrc:/StageRock.qml" << "qrc:/StageTheatre.qml";
+
+    m_genericItemsList = new ListModel(this);
+    QStringList listRoles;
+    listRoles << "itemID" << "name" << "isSelected";
+    m_genericItemsList->setRoleNames(listRoles);
 }
 
 MainView3D::~MainView3D()
@@ -637,7 +647,7 @@ void MainView3D::getMeshCorners(QGeometryRenderer *mesh,
 
     if (!meshGeometry)
         return;
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Qt3DRender::QAttribute *vPosAttribute = nullptr;
     for (Qt3DRender::QAttribute *attribute : meshGeometry->attributes())
     {
@@ -647,6 +657,17 @@ void MainView3D::getMeshCorners(QGeometryRenderer *mesh,
             break;
         }
     }
+#else
+    Qt3DCore::QAttribute *vPosAttribute = nullptr;
+    for (Qt3DCore::QAttribute *attribute : meshGeometry->attributes())
+    {
+        if (attribute->name() == Qt3DCore::QAttribute::defaultPositionAttributeName())
+        {
+            vPosAttribute = attribute;
+            break;
+        }
+    }
+#endif
     if (vPosAttribute)
     {
         const float *bufferPtr =
@@ -720,7 +741,7 @@ void MainView3D::addVolumes(SceneItem *meshRef, QVector3D minCorner, QVector3D m
                                            vminY + meshRef->m_volume.m_extents.y() / 2.0f,
                                            vminZ + meshRef->m_volume.m_extents.z() / 2.0f);
 
-    qDebug() << "-- extent" << meshRef->m_volume.m_extents << "-- center" << meshRef->m_volume.m_center;
+    //qDebug() << "-- extent" << meshRef->m_volume.m_extents << "-- center" << meshRef->m_volume.m_center;
 }
 
 QEntity *MainView3D::inspectEntity(QEntity *entity, SceneItem *meshRef,
@@ -1547,9 +1568,10 @@ void MainView3D::initializeItem(int itemID, QEntity *itemEntity, QSceneLoader *l
 
     // Walk through the scene tree and add each mesh to the deferred pipeline.
     // If needed, calculate also the bounding volume */
-    /*QEntity *baseItem =*/ inspectEntity(root, meshRef, sceneDeferredLayer, sceneEffect, calculateVolume, translation);
+    inspectEntity(root, meshRef, sceneDeferredLayer, sceneEffect, calculateVolume, translation);
 
-    qDebug() << "Calculated volume" << meshRef->m_volume.m_extents << meshRef->m_volume.m_center;
+    qDebug() << "Calculated volume:" << meshRef->m_volume.m_extents << ", center:" << meshRef->m_volume.m_center;
+    qDebug() << "Translation:" << translation;
 
     if (calculateVolume)
         m_boundingVolumesMap[loader->source()] = meshRef->m_volume;
@@ -1580,6 +1602,7 @@ void MainView3D::initializeItem(int itemID, QEntity *itemEntity, QSceneLoader *l
 
     itemEntity->setProperty("sceneLayer", QVariant::fromValue(sceneDeferredLayer));
     itemEntity->setProperty("effect", QVariant::fromValue(sceneEffect));
+    updateGenericItemsList();
 }
 
 void MainView3D::setItemSelection(int itemID, bool enable, int keyModifiers)
@@ -1636,6 +1659,58 @@ void MainView3D::removeSelectedGenericItems()
     }
     m_genericSelectedItems.clear();
     emit genericSelectedCountChanged();
+    updateGenericItemsList();
+}
+
+void MainView3D::normalizeSelectedGenericItems()
+{
+    for (int id : m_genericSelectedItems)
+    {
+        SceneItem *meshRef = m_genericMap.value(id, nullptr);
+        if (meshRef)
+        {
+            // adjust the item scale to target size
+            float factor = 1.0;
+            float targetSize = 2.0;
+
+            if (targetSize / meshRef->m_volume.m_extents.x() < factor)
+                factor = targetSize / meshRef->m_volume.m_extents.x();
+
+            if (targetSize / meshRef->m_volume.m_extents.y() < factor)
+                factor = targetSize / meshRef->m_volume.m_extents.y();
+
+            if (targetSize / meshRef->m_volume.m_extents.z() < factor)
+                factor = targetSize / meshRef->m_volume.m_extents.z();
+
+            updateGenericItemScale(id, QVector3D(factor, factor, factor));
+
+            // adjust the item position to scene origin
+            updateGenericItemPosition(id, QVector3D(meshRef->m_volume.m_center.x() * -1000.0,
+                                                    meshRef->m_volume.m_center.y() * -1000.0,
+                                                    meshRef->m_volume.m_center.z() * -1000.0));
+        }
+    }
+}
+
+void MainView3D::updateGenericItemsList()
+{
+    m_genericItemsList->clear();
+
+    for (quint32 itemID : m_monProps->genericItemsID())
+    {
+        QVariantMap itemMap;
+        itemMap.insert("itemID", itemID);
+        itemMap.insert("name", m_monProps->itemName(itemID));
+        itemMap.insert("isSelected", false);
+        m_genericItemsList->addDataMap(itemMap);
+    }
+
+    emit genericItemsListChanged();
+}
+
+QVariant MainView3D::genericItemsList() const
+{
+    return QVariant::fromValue(m_genericItemsList);
 }
 
 void MainView3D::updateGenericItemPosition(quint32 itemID, QVector3D pos)
