@@ -29,7 +29,6 @@
 #include "inputpatch.h"
 #include "treemodel.h"
 #include "vccuelist.h"
-#include "vcwidget.h"
 #include "vcbutton.h"
 #include "vcslider.h"
 #include "vcframe.h"
@@ -40,20 +39,20 @@
 #include "doc.h"
 #include "app.h"
 
-#define KXMLQLCVCProperties "Properties"
-#define KXMLQLCVCPropertiesSize "Size"
-#define KXMLQLCVCPropertiesSizeWidth "Width"
-#define KXMLQLCVCPropertiesSizeHeight "Height"
+#define KXMLQLCVCProperties             QString("Properties")
+#define KXMLQLCVCPropertiesSize         QString("Size")
+#define KXMLQLCVCPropertiesSizeWidth    QString("Width")
+#define KXMLQLCVCPropertiesSizeHeight   QString("Height")
 
-#define KXMLQLCVCPropertiesGrandMaster "GrandMaster"
-#define KXMLQLCVCPropertiesGrandMasterVisible "Visible"
-#define KXMLQLCVCPropertiesGrandMasterChannelMode "ChannelMode"
-#define KXMLQLCVCPropertiesGrandMasterValueMode "ValueMode"
-#define KXMLQLCVCPropertiesGrandMasterSliderMode "SliderMode"
+#define KXMLQLCVCPropertiesGrandMaster              QString("GrandMaster")
+#define KXMLQLCVCPropertiesGrandMasterVisible       QString("Visible")
+#define KXMLQLCVCPropertiesGrandMasterChannelMode   QString("ChannelMode")
+#define KXMLQLCVCPropertiesGrandMasterValueMode     QString("ValueMode")
+#define KXMLQLCVCPropertiesGrandMasterSliderMode    QString("SliderMode")
 
-#define KXMLQLCVCPropertiesInput "Input"
-#define KXMLQLCVCPropertiesInputUniverse "Universe"
-#define KXMLQLCVCPropertiesInputChannel "Channel"
+#define KXMLQLCVCPropertiesInput            QString("Input")
+#define KXMLQLCVCPropertiesInputUniverse    QString("Universe")
+#define KXMLQLCVCPropertiesInputChannel     QString("Channel")
 
 #define DEFAULT_VC_PAGES_NUMBER 4
 
@@ -579,10 +578,6 @@ QVariantList VirtualConsole::selectedWidgetIDs()
 
 void VirtualConsole::moveWidget(VCWidget *widget, VCFrame *targetFrame, QPoint pos)
 {
-    // reset all the drop targets, otherwise two overlapping
-    // frames can get the same drop event
-    resetDropTargets(true);
-
     VCFrame *sourceFrame = qobject_cast<VCFrame*>(widget->parent());
 
     if (sourceFrame != targetFrame)
@@ -866,45 +861,6 @@ int VirtualConsole::clipboardItemsCount() const
     return m_clipboardIDList.count();
 }
 
-/*********************************************************************
- * Drag & Drop
- *********************************************************************/
-
-void VirtualConsole::setDropTarget(QQuickItem *target, bool enable)
-{
-    if (enable == true)
-    {
-        resetDropTargets(false);
-        m_dropTargets << target;
-        target->setProperty("dropActive", true);
-    }
-    else
-    {
-        for (int i = 0; i < m_dropTargets.count(); i++)
-        {
-            if (m_dropTargets.at(i) == target)
-            {
-                m_dropTargets.at(i)->setProperty("dropActive", false);
-                if (i > 0)
-                    m_dropTargets.at(i - 1)->setProperty("dropActive", true);
-                m_dropTargets.removeLast();
-                return;
-            }
-        }
-    }
-}
-
-void VirtualConsole::resetDropTargets(bool deleteTargets)
-{
-    foreach(QQuickItem *item, m_dropTargets)
-        item->setProperty("dropActive", false);
-
-    if (deleteTargets)
-        m_dropTargets.clear();
-}
-
-
-
 /*********************************************************************
  * External input
  *********************************************************************/
