@@ -23,11 +23,15 @@ var testAlgo;
 
 (function()
   {
+    var util = new Object;
+
+    let geometryCalc = new Object;
+
     var algo = new Object;
     algo.apiVersion = 2;
     algo.name = "Flying Objects";
     algo.author = "Hans-Jürgen Tappe";
-    algo.acceptColors = 2;
+    algo.acceptColors = 1;
     algo.properties = new Array();
 
     // Algorithms ----------------------------
@@ -141,7 +145,6 @@ var testAlgo;
         // The bottom:
         // offx remains the same.
         // offy is 0
-        let realOffy = offy - candleAlgo.cache.bottomHeight;
         distance = Math.sqrt((offx * offx) + 1);
         factor = Math.max(factor, 1 - (distance / candleAlgo.cache.bottomWidth));
       }
@@ -231,7 +234,6 @@ var testAlgo;
       if (eyeAlgo.cache.presetRadius != algo.presetRadius) {
         eyeAlgo.updateCache();
       }
-      let tips = 0;
       // calculate the offset difference of algo.map location to the float
       // location of the object
       let offx = rx - algo.obj[i].x;
@@ -723,7 +725,6 @@ var testAlgo;
       let offy = ry - algo.obj[i].y;
       let distance = Math.sqrt(offx * offx + offy * offy);
       let angle = geometryCalc.getAngle(offx, offy);
-      let baseIntensity = 0;
       let percent = 0;
       let factor = 0;
       
@@ -1084,7 +1085,6 @@ var testAlgo;
 
     // General Purpose Functions ------------------
 
-    let geometryCalc = new Object;
     geometryCalc.cache = {
       presetRadius: 0,
     };
@@ -1147,7 +1147,6 @@ var testAlgo;
     }
     
     // Utility functions --------------------------
-    var util = new Object;
 
     util.initialize = function(width, height)
     {
